package com.temboo.Library.Amazon.Marketplace.Feeds;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UpdatePriceAndQuantity

Updates only the price and quantity of a particular product with a given product SKU.
*/
public class UpdatePriceAndQuantity extends Choreography {

	/**
	Create a new instance of the UpdatePriceAndQuantity Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UpdatePriceAndQuantity(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/Marketplace/Feeds/UpdatePriceAndQuantity"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UpdatePriceAndQuantityInputSet
	*/
	public UpdatePriceAndQuantityInputSet newInputSet() {
		return new UpdatePriceAndQuantityInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UpdatePriceAndQuantityResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UpdatePriceAndQuantityResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UpdatePriceAndQuantity
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UpdatePriceAndQuantityInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSMarketplaceId input for this Choreo. 

		@param String - (required, string) The Marketplace ID provided by Amazon Web Services.
		*/
		public void set_AWSMarketplaceId(String value) {
			this.setInput("AWSMarketplaceId", value);
		}


		/** 
		Set the value of the AWSMerchantId input for this Choreo. 

		@param String - (required, string) The Merchant ID provided by Amazon Web Services.
		*/
		public void set_AWSMerchantId(String value) {
			this.setInput("AWSMerchantId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (conditional, string) The base URL for the MWS endpoint. Defaults to mws.amazonservices.co.uk.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}


		/** 
		Set the value of the MWSAuthToken input for this Choreo. 

		@param String - (optional, string) The Amazon MWS authorization token for the given seller and developer.
		*/
		public void set_MWSAuthToken(String value) {
			this.setInput("MWSAuthToken", value);
		}


		/** 
		Set the value of the Price input for this Choreo. 

		@param BigDecimal - (required, decimal) Enter the unit price for this product. The price must be greater than 0.00. Do NOT include the currency symbol (e.g. $).
		*/
		public void set_Price(BigDecimal value) {
			this.setInput("Price", value);
		}

		/** 
		Set the value of the Price input for this Choreo as a String. 

		@param String - (required, decimal) Enter the unit price for this product. The price must be greater than 0.00. Do NOT include the currency symbol (e.g. $).
		*/
		public void set_Price(String value) {
			this.setInput("Price", value);	
		}
		/** 
		Set the value of the Quantity input for this Choreo. 

		@param Integer - (required, integer) Enter the quantity of the product you have for sale. The quantity must be a whole number, and should be greater than zero.
		*/
		public void set_Quantity(Integer value) {
			this.setInput("Quantity", value);
		}

		/** 
		Set the value of the Quantity input for this Choreo as a String. 

		@param String - (required, integer) Enter the quantity of the product you have for sale. The quantity must be a whole number, and should be greater than zero.
		*/
		public void set_Quantity(String value) {
			this.setInput("Quantity", value);	
		}
		/** 
		Set the value of the SKU input for this Choreo. 

		@param String - (required, string) A SKU is a "Stock Keeping Unit" which you can assign to your products to track your inventory. Provide the SKU that you want to modify.
		*/
		public void set_SKU(String value) {
			this.setInput("SKU", value);
		}


		/** 
		Set the value of the TimeToWait input for this Choreo. 

		@param Integer - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(Integer value) {
			this.setInput("TimeToWait", value);
		}

		/** 
		Set the value of the TimeToWait input for this Choreo as a String. 

		@param String - (optional, integer) By default, the Choreo will wait for 10 minutes to see if the report is ready for retrieval. Max is 120 minutes.
		*/
		public void set_TimeToWait(String value) {
			this.setInput("TimeToWait", value);	
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UpdatePriceAndQuantity Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UpdatePriceAndQuantityResultSet extends ResultSet {
		public UpdatePriceAndQuantityResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ProcessingStatus" output from this Choreo execution

		@return String - (string) The processing status of the feed submission which is parsed from the Amazon response.
		*/
		public String get_ProcessingStatus() {
			return this.getResultString("ProcessingStatus");
		}
		/** 
		Retrieve the value for the "SubmissionId" output from this Choreo execution

		@return String - (integer) The submission id parsed from the Amazon response.
		*/
		public String get_SubmissionId() {
			return this.getResultString("SubmissionId");
		}
		/** 
		Retrieve the value for the "SubmissionResult" output from this Choreo execution

		@return String - (string) The submission result returned from Amazon.
		*/
		public String get_SubmissionResult() {
			return this.getResultString("SubmissionResult");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon after submitting the feed.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
