package com.temboo.Library.Amazon.RDS;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
DescribeDBSecurityGroup

Returns a list of DBSecurityGroup descriptions. The list will can be filtered by specifying a DBSecurityGroupName.
*/
public class DescribeDBSecurityGroup extends Choreography {

	/**
	Create a new instance of the DescribeDBSecurityGroup Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public DescribeDBSecurityGroup(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Amazon/RDS/DescribeDBSecurityGroup"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return DescribeDBSecurityGroupInputSet
	*/
	public DescribeDBSecurityGroupInputSet newInputSet() {
		return new DescribeDBSecurityGroupInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public DescribeDBSecurityGroupResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new DescribeDBSecurityGroupResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the DescribeDBSecurityGroup
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class DescribeDBSecurityGroupInputSet extends InputSet {
		/** 
		Set the value of the AWSAccessKeyId input for this Choreo. 

		@param String - (required, string) The Access Key ID provided by Amazon Web Services.
		*/
		public void set_AWSAccessKeyId(String value) {
			this.setInput("AWSAccessKeyId", value);
		}


		/** 
		Set the value of the AWSSecretKeyId input for this Choreo. 

		@param String - (required, string) The Secret Key ID provided by Amazon Web Services.
		*/
		public void set_AWSSecretKeyId(String value) {
			this.setInput("AWSSecretKeyId", value);
		}


		/** 
		Set the value of the DBSecurityGroupName input for this Choreo. 

		@param String - (optional, string) The name for the security group you want to retrieve information for.
		*/
		public void set_DBSecurityGroupName(String value) {
			this.setInput("DBSecurityGroupName", value);
		}


		/** 
		Set the value of the Marker input for this Choreo. 

		@param Integer - (optional, integer) If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
		*/
		public void set_Marker(Integer value) {
			this.setInput("Marker", value);
		}

		/** 
		Set the value of the Marker input for this Choreo as a String. 

		@param String - (optional, integer) If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
		*/
		public void set_Marker(String value) {
			this.setInput("Marker", value);	
		}
		/** 
		Set the value of the MaxRecords input for this Choreo. 

		@param Integer - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
		*/
		public void set_MaxRecords(Integer value) {
			this.setInput("MaxRecords", value);
		}

		/** 
		Set the value of the MaxRecords input for this Choreo as a String. 

		@param String - (optional, integer) The max number of results to return in the response. Defaults to 100. Minimum is 20.
		*/
		public void set_MaxRecords(String value) {
			this.setInput("MaxRecords", value);	
		}
		/** 
		Set the value of the UserRegion input for this Choreo. 

		@param String - (optional, string) The AWS region that corresponds to the RDS endpoint you wish to access. The default region is "us-east-1". See description below for valid values.
		*/
		public void set_UserRegion(String value) {
			this.setInput("UserRegion", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the DescribeDBSecurityGroup Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class DescribeDBSecurityGroupResultSet extends ResultSet {
		public DescribeDBSecurityGroupResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Amazon.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
