package com.temboo.Library.AuthorizeNet.CustomerInformationManager;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetCustomerProfileIds

Retrieves all existing customer profile IDs.
*/
public class GetCustomerProfileIds extends Choreography {

	/**
	Create a new instance of the GetCustomerProfileIds Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetCustomerProfileIds(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/AuthorizeNet/CustomerInformationManager/GetCustomerProfileIds"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetCustomerProfileIdsInputSet
	*/
	public GetCustomerProfileIdsInputSet newInputSet() {
		return new GetCustomerProfileIdsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetCustomerProfileIdsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetCustomerProfileIdsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetCustomerProfileIds
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetCustomerProfileIdsInputSet extends InputSet {
		/** 
		Set the value of the APILoginId input for this Choreo. 

		@param String - (required, string) The API Login Id provided by Authorize.net when signing up for a developer account.
		*/
		public void set_APILoginId(String value) {
			this.setInput("APILoginId", value);
		}


		/** 
		Set the value of the Endpoint input for this Choreo. 

		@param String - (optional, string) Set to api.authorize.net when running in production. Defaults to apitest.authorize.net for sandbox testing.
		*/
		public void set_Endpoint(String value) {
			this.setInput("Endpoint", value);
		}


		/** 
		Set the value of the TransactionKey input for this Choreo. 

		@param String - (required, string) The TransactionKey provided by Authorize.net when signing up for a developer account.
		*/
		public void set_TransactionKey(String value) {
			this.setInput("TransactionKey", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetCustomerProfileIds Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetCustomerProfileIdsResultSet extends ResultSet {
		public GetCustomerProfileIdsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (xml) The response from Authorize.net.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
