package com.temboo.Library.Salesforce.Objects;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetRecordByExternalID

Retrieve records with a specific external ID.
*/
public class GetRecordByExternalID extends Choreography {

	/**
	Create a new instance of the GetRecordByExternalID Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetRecordByExternalID(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Salesforce/Objects/GetRecordByExternalID"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetRecordByExternalIDInputSet
	*/
	public GetRecordByExternalIDInputSet newInputSet() {
		return new GetRecordByExternalIDInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetRecordByExternalIDResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetRecordByExternalIDResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetRecordByExternalID
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetRecordByExternalIDInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Salesforce. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}


		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Salesforce. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}


		/** 
		Set the value of the FieldName input for this Choreo. 

		@param String - (conditional, string) FieldName for external ID
		*/
		public void set_FieldName(String value) {
			this.setInput("FieldName", value);
		}


		/** 
		Set the value of the FieldValue input for this Choreo. 

		@param String - (conditional, string) Field value for external ID
		*/
		public void set_FieldValue(String value) {
			this.setInput("FieldValue", value);
		}


		/** 
		Set the value of the InstanceName input for this Choreo. 

		@param String - (required, string) The server url prefix that indicates which instance your Salesforce account is on (e.g. na1, na2, na3, etc).
		*/
		public void set_InstanceName(String value) {
			this.setInput("InstanceName", value);
		}


		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth Refresh Token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should be in. Valid values are: json (the default) and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the SObjectName input for this Choreo. 

		@param String - (conditional, string) The name of the Salesforce object type being created (e.g. Account, Contact, Lead, etc).
		*/
		public void set_SObjectName(String value) {
			this.setInput("SObjectName", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetRecordByExternalID Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetRecordByExternalIDResultSet extends ResultSet {
		public GetRecordByExternalIDResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResultString("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Salesforce.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
