package com.temboo.Library.Stripe.Plans;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
CreatePlan

Creates a subscription plan
*/
public class CreatePlan extends Choreography {

	/**
	Create a new instance of the CreatePlan Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public CreatePlan(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Plans/CreatePlan"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return CreatePlanInputSet
	*/
	public CreatePlanInputSet newInputSet() {
		return new CreatePlanInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public CreatePlanResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new CreatePlanResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the CreatePlan
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class CreatePlanInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the Amount input for this Choreo. 

		@param Integer - (required, integer) The amount in cents to charge on a recurring basis for subscribers of this plan
		*/
		public void set_Amount(Integer value) {
			this.setInput("Amount", value);
		}

		/** 
		Set the value of the Amount input for this Choreo as a String. 

		@param String - (required, integer) The amount in cents to charge on a recurring basis for subscribers of this plan
		*/
		public void set_Amount(String value) {
			this.setInput("Amount", value);	
		}
		/** 
		Set the value of the Currency input for this Choreo. 

		@param String - (optional, string) 3-letter ISO code for currency. Defaults to 'usd' which is currently the only supported currency.
		*/
		public void set_Currency(String value) {
			this.setInput("Currency", value);
		}


		/** 
		Set the value of the Interval input for this Choreo. 

		@param String - (required, string) Indicates billing frequency. Valid values are: month or year.
		*/
		public void set_Interval(String value) {
			this.setInput("Interval", value);
		}


		/** 
		Set the value of the PlanID input for this Choreo. 

		@param String - (required, string) The unique identifier of the plan you want to create
		*/
		public void set_PlanID(String value) {
			this.setInput("PlanID", value);
		}


		/** 
		Set the value of the PlanName input for this Choreo. 

		@param String - (required, string) The name of the plan which will be displayed in the Stripe web interface.
		*/
		public void set_PlanName(String value) {
			this.setInput("PlanName", value);
		}


		/** 
		Set the value of the TrialPeriodDays input for this Choreo. 

		@param Integer - (optional, integer) The number of days in a trial period (customer will not be billed until the trial period is over)
		*/
		public void set_TrialPeriodDays(Integer value) {
			this.setInput("TrialPeriodDays", value);
		}

		/** 
		Set the value of the TrialPeriodDays input for this Choreo as a String. 

		@param String - (optional, integer) The number of days in a trial period (customer will not be billed until the trial period is over)
		*/
		public void set_TrialPeriodDays(String value) {
			this.setInput("TrialPeriodDays", value);	
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the CreatePlan Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class CreatePlanResultSet extends ResultSet {
		public CreatePlanResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
