package com.temboo.Library.Twitter.Timelines;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
UserTimeline

Retrieves a collection of the most recent Tweets posted by the user whose screen_name or user_id is indicated.
*/
public class UserTimeline extends Choreography {

	/**
	Create a new instance of the UserTimeline Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public UserTimeline(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Twitter/Timelines/UserTimeline"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return UserTimelineInputSet
	*/
	public UserTimelineInputSet newInputSet() {
		return new UserTimelineInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public UserTimelineResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new UserTimelineResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the UserTimeline
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class UserTimelineInputSet extends InputSet {
		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (conditional, string) The Access Token provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the AccessTokenSecret input for this Choreo. 

		@param String - (conditional, string) The Access Token Secret provided by Twitter or retrieved during the OAuth process.
		*/
		public void set_AccessTokenSecret(String value) {
			this.setInput("AccessTokenSecret", value);
		}


		/** 
		Set the value of the ConsumerKey input for this Choreo. 

		@param String - (conditional, string) The API Key (or Consumer Key) provided by Twitter.
		*/
		public void set_ConsumerKey(String value) {
			this.setInput("ConsumerKey", value);
		}


		/** 
		Set the value of the ConsumerSecret input for this Choreo. 

		@param String - (conditional, string) The API Secret (or Consumer Secret) provided by Twitter.
		*/
		public void set_ConsumerSecret(String value) {
			this.setInput("ConsumerSecret", value);
		}


		/** 
		Set the value of the ContributorDetails input for this Choreo. 

		@param Boolean - (optional, boolean) Set to true to include the screen_name of the contributor. By default only the user_id of the contributor is included.
		*/
		public void set_ContributorDetails(Boolean value) {
			this.setInput("ContributorDetails", value);
		}

		/** 
		Set the value of the ContributorDetails input for this Choreo as a String. 

		@param String - (optional, boolean) Set to true to include the screen_name of the contributor. By default only the user_id of the contributor is included.
		*/
		public void set_ContributorDetails(String value) {
			this.setInput("ContributorDetails", value);	
		}
		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) Specifies the number of records to retrieve. Must be less than or equal to 200. Defaults to 20.
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) Specifies the number of records to retrieve. Must be less than or equal to 200. Defaults to 20.
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}
		/** 
		Set the value of the ExcludeReplies input for this Choreo. 

		@param Boolean - (optional, boolean) Set to true to prevent replies from appearing in the returned timeline.
		*/
		public void set_ExcludeReplies(Boolean value) {
			this.setInput("ExcludeReplies", value);
		}

		/** 
		Set the value of the ExcludeReplies input for this Choreo as a String. 

		@param String - (optional, boolean) Set to true to prevent replies from appearing in the returned timeline.
		*/
		public void set_ExcludeReplies(String value) {
			this.setInput("ExcludeReplies", value);	
		}
		/** 
		Set the value of the IncludeRetweets input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeRetweets(Boolean value) {
			this.setInput("IncludeRetweets", value);
		}

		/** 
		Set the value of the IncludeRetweets input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, the response will include the "entities" node.
		*/
		public void set_IncludeRetweets(String value) {
			this.setInput("IncludeRetweets", value);	
		}
		/** 
		Set the value of the MaxId input for this Choreo. 

		@param String - (optional, string) Returns results with an ID less than (older than) or equal to the specified ID.
		*/
		public void set_MaxId(String value) {
			this.setInput("MaxId", value);
		}


		/** 
		Set the value of the ScreenName input for this Choreo. 

		@param String - (conditional, string) Screen name of the user to return results for. Required unless providing the UserId.
		*/
		public void set_ScreenName(String value) {
			this.setInput("ScreenName", value);
		}


		/** 
		Set the value of the SinceId input for this Choreo. 

		@param String - (optional, string) Returns results with an ID greater than (more recent than) the specified ID.
		*/
		public void set_SinceId(String value) {
			this.setInput("SinceId", value);
		}


		/** 
		Set the value of the TrimUser input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID. Defaults to false.
		*/
		public void set_TrimUser(Boolean value) {
			this.setInput("TrimUser", value);
		}

		/** 
		Set the value of the TrimUser input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, each tweet returned in a timeline will include a user object including only the status authors numerical ID. Defaults to false.
		*/
		public void set_TrimUser(String value) {
			this.setInput("TrimUser", value);	
		}
		/** 
		Set the value of the UserId input for this Choreo. 

		@param String - (conditional, string) ID of the user to return results for. Required unless providing the ScreenName.
		*/
		public void set_UserId(String value) {
			this.setInput("UserId", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the UserTimeline Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class UserTimelineResultSet extends ResultSet {
		public UserTimelineResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Limit" output from this Choreo execution

		@return String - (integer) The rate limit ceiling for this particular request.
		*/
		public String get_Limit() {
			return this.getResultString("Limit");
		}
		/** 
		Retrieve the value for the "Remaining" output from this Choreo execution

		@return String - (integer) The number of requests left for the 15 minute window.
		*/
		public String get_Remaining() {
			return this.getResultString("Remaining");
		}
		/** 
		Retrieve the value for the "Reset" output from this Choreo execution

		@return String - (date) The remaining window before the rate limit resets in UTC epoch seconds.
		*/
		public String get_Reset() {
			return this.getResultString("Reset");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Twitter.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
